"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Status:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Status.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STATUS_UNSPECIFIED: _Status.ValueType  # 0
    """Status is not specified."""
    COLLECTING: _Status.ValueType  # 1
    """Report is being collected."""
    CALCULATING: _Status.ValueType  # 2
    """Report is being calculated."""
    READY: _Status.ValueType  # 3
    """Report is ready."""

class Status(_Status, metaclass=_StatusEnumTypeWrapper):
    """Report status."""

STATUS_UNSPECIFIED: Status.ValueType  # 0
"""Status is not specified."""
COLLECTING: Status.ValueType  # 1
"""Report is being collected."""
CALCULATING: Status.ValueType  # 2
"""Report is being calculated."""
READY: Status.ValueType  # 3
"""Report is ready."""
global___Status = Status



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/video/v1/subtitle.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/video/v1/subtitle.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$yandex/cloud/video/v1/subtitle.proto\x12\x15yandex.cloud.video.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8d\x04\n\x08Subtitle\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12>\n\x06status\x18\x04 \x01(\x0e\x32..yandex.cloud.video.v1.Subtitle.SubtitleStatus\x12G\n\x0bsource_type\x18\x06 \x01(\x0e\x32\x32.yandex.cloud.video.v1.Subtitle.SubtitleSourceType\x12\x10\n\x08\x66ilename\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x65 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x08video_id\x18\xe8\x07 \x01(\tH\x00\"S\n\x0eSubtitleStatus\x12\x1f\n\x1bSUBTITLE_STATUS_UNSPECIFIED\x10\x00\x12\x12\n\x0eWAIT_UPLOADING\x10\x01\x12\x0c\n\x08UPLOADED\x10\x02\"U\n\x12SubtitleSourceType\x12$\n SUBTITLE_SOURCE_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\r\n\tGENERATED\x10\x02\x42\x0b\n\tparent_idJ\x04\x08\x07\x10\x64J\x05\x08\x66\x10\xe8\x07\x42\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.subtitle_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_SUBTITLE']._serialized_start=97
  _globals['_SUBTITLE']._serialized_end=622
  _globals['_SUBTITLE_SUBTITLESTATUS']._serialized_start=426
  _globals['_SUBTITLE_SUBTITLESTATUS']._serialized_end=509
  _globals['_SUBTITLE_SUBTITLESOURCETYPE']._serialized_start=511
  _globals['_SUBTITLE_SUBTITLESOURCETYPE']._serialized_end=596
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/clickhouse/v1/database_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/clickhouse/v1/database_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.clickhouse.v1 import database_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_database__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/mdb/clickhouse/v1/database_service.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a-yandex/cloud/mdb/clickhouse/v1/database.proto\"m\n\x12GetDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rdatabase_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"v\n\x14ListDatabasesRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"m\n\x15ListDatabasesResponse\x12;\n\tdatabases\x18\x01 \x03(\x0b\x32(.yandex.cloud.mdb.clickhouse.v1.Database\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x84\x01\n\x15\x43reateDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12I\n\rdatabase_spec\x18\x02 \x01(\x0b\x32,.yandex.cloud.mdb.clickhouse.v1.DatabaseSpecB\x04\xe8\xc7\x31\x01\"C\n\x16\x43reateDatabaseMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"p\n\x15\x44\x65leteDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rdatabase_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"C\n\x16\x44\x65leteDatabaseMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t2\xb4\x06\n\x0f\x44\x61tabaseService\x12\xb3\x01\n\x03Get\x12\x32.yandex.cloud.mdb.clickhouse.v1.GetDatabaseRequest\x1a(.yandex.cloud.mdb.clickhouse.v1.Database\"N\x82\xd3\xe4\x93\x02H\x12\x46/managed-clickhouse/v1/clusters/{cluster_id}/databases/{database_name}\x12\xb3\x01\n\x04List\x12\x34.yandex.cloud.mdb.clickhouse.v1.ListDatabasesRequest\x1a\x35.yandex.cloud.mdb.clickhouse.v1.ListDatabasesResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/managed-clickhouse/v1/clusters/{cluster_id}/databases\x12\xcb\x01\n\x06\x43reate\x12\x35.yandex.cloud.mdb.clickhouse.v1.CreateDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"g\xb2\xd2*\"\n\x16\x43reateDatabaseMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02;\"6/managed-clickhouse/v1/clusters/{cluster_id}/databases:\x01*\x12\xe6\x01\n\x06\x44\x65lete\x12\x35.yandex.cloud.mdb.clickhouse.v1.DeleteDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"\x81\x01\xb2\xd2*/\n\x16\x44\x65leteDatabaseMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02H*F/managed-clickhouse/v1/clusters/{cluster_id}/databases/{database_name}Bs\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.database_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse'
  _globals['_GETDATABASEREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETDATABASEREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETDATABASEREQUEST'].fields_by_name['database_name']._loaded_options = None
  _globals['_GETDATABASEREQUEST'].fields_by_name['database_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_LISTDATABASESREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTDATABASESREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDATABASESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDATABASESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTDATABASESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDATABASESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATEDATABASEREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATEDATABASEREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEDATABASEREQUEST'].fields_by_name['database_spec']._loaded_options = None
  _globals['_CREATEDATABASEREQUEST'].fields_by_name['database_spec']._serialized_options = b'\350\3071\001'
  _globals['_DELETEDATABASEREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETEDATABASEREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEDATABASEREQUEST'].fields_by_name['database_name']._loaded_options = None
  _globals['_DELETEDATABASEREQUEST'].fields_by_name['database_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_DATABASESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_DATABASESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002H\022F/managed-clickhouse/v1/clusters/{cluster_id}/databases/{database_name}'
  _globals['_DATABASESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_DATABASESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\0028\0226/managed-clickhouse/v1/clusters/{cluster_id}/databases'
  _globals['_DATABASESERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_DATABASESERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateDatabaseMetadata\022\010Database\202\323\344\223\002;\"6/managed-clickhouse/v1/clusters/{cluster_id}/databases:\001*'
  _globals['_DATABASESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_DATABASESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteDatabaseMetadata\022\025google.protobuf.Empty\202\323\344\223\002H*F/managed-clickhouse/v1/clusters/{cluster_id}/databases/{database_name}'
  _globals['_GETDATABASEREQUEST']._serialized_start=271
  _globals['_GETDATABASEREQUEST']._serialized_end=380
  _globals['_LISTDATABASESREQUEST']._serialized_start=382
  _globals['_LISTDATABASESREQUEST']._serialized_end=500
  _globals['_LISTDATABASESRESPONSE']._serialized_start=502
  _globals['_LISTDATABASESRESPONSE']._serialized_end=611
  _globals['_CREATEDATABASEREQUEST']._serialized_start=614
  _globals['_CREATEDATABASEREQUEST']._serialized_end=746
  _globals['_CREATEDATABASEMETADATA']._serialized_start=748
  _globals['_CREATEDATABASEMETADATA']._serialized_end=815
  _globals['_DELETEDATABASEREQUEST']._serialized_start=817
  _globals['_DELETEDATABASEREQUEST']._serialized_end=929
  _globals['_DELETEDATABASEMETADATA']._serialized_start=931
  _globals['_DELETEDATABASEMETADATA']._serialized_end=998
  _globals['_DATABASESERVICE']._serialized_start=1001
  _globals['_DATABASESERVICE']._serialized_end=1821
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class User(google.protobuf.message.Message):
    """A Redis User resource. For more information, see the
    [Developer's Guide](/docs/managed-redis/concepts).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ACL_OPTIONS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the Redis user."""
    cluster_id: builtins.str
    """ID of the Redis cluster the user belongs to."""
    enabled: builtins.bool
    """Is redis user enabled"""
    acl_options: builtins.str
    """Raw ACL string inside of Redis"""
    @property
    def permissions(self) -> global___Permissions:
        """Set of permissions to grant to the user."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        permissions: global___Permissions | None = ...,
        enabled: builtins.bool = ...,
        acl_options: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["permissions", b"permissions"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["acl_options", b"acl_options", "cluster_id", b"cluster_id", "enabled", b"enabled", "name", b"name", "permissions", b"permissions"]) -> None: ...

global___User = User

@typing.final
class Permissions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATTERNS_FIELD_NUMBER: builtins.int
    PUB_SUB_CHANNELS_FIELD_NUMBER: builtins.int
    CATEGORIES_FIELD_NUMBER: builtins.int
    COMMANDS_FIELD_NUMBER: builtins.int
    SANITIZE_PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def patterns(self) -> google.protobuf.wrappers_pb2.StringValue:
        """Keys patterns user has permission to."""

    @property
    def pub_sub_channels(self) -> google.protobuf.wrappers_pb2.StringValue:
        """Channel patterns user has permissions to."""

    @property
    def categories(self) -> google.protobuf.wrappers_pb2.StringValue:
        """Command categories user has permissions to."""

    @property
    def commands(self) -> google.protobuf.wrappers_pb2.StringValue:
        """Commands user can execute."""

    @property
    def sanitize_payload(self) -> google.protobuf.wrappers_pb2.StringValue:
        """SanitizePayload parameter."""

    def __init__(
        self,
        *,
        patterns: google.protobuf.wrappers_pb2.StringValue | None = ...,
        pub_sub_channels: google.protobuf.wrappers_pb2.StringValue | None = ...,
        categories: google.protobuf.wrappers_pb2.StringValue | None = ...,
        commands: google.protobuf.wrappers_pb2.StringValue | None = ...,
        sanitize_payload: google.protobuf.wrappers_pb2.StringValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["categories", b"categories", "commands", b"commands", "patterns", b"patterns", "pub_sub_channels", b"pub_sub_channels", "sanitize_payload", b"sanitize_payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["categories", b"categories", "commands", b"commands", "patterns", b"patterns", "pub_sub_channels", b"pub_sub_channels", "sanitize_payload", b"sanitize_payload"]) -> None: ...

global___Permissions = Permissions

@typing.final
class UserSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PASSWORDS_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the Redis user."""
    @property
    def passwords(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Password of the Redis user."""

    @property
    def permissions(self) -> global___Permissions:
        """Set of permissions to grant to the user."""

    @property
    def enabled(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Is Redis user enabled"""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        passwords: collections.abc.Iterable[builtins.str] | None = ...,
        permissions: global___Permissions | None = ...,
        enabled: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["enabled", b"enabled", "permissions", b"permissions"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["enabled", b"enabled", "name", b"name", "passwords", b"passwords", "permissions", b"permissions"]) -> None: ...

global___UserSpec = UserSpec



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.postgresql.v1.backup_retention_policy_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListBackupRetentionPoliciesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster.
    To get the PostgreSQL cluster ID use a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListBackupRetentionPoliciesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListBackupRetentionPoliciesResponse.next_page_token] returned by the previous list request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListBackupRetentionPoliciesRequest = ListBackupRetentionPoliciesRequest

@typing.final
class ListBackupRetentionPoliciesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICIES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListBackupRetentionPoliciesRequest.page_size], use the [next_page_token] as the value
    for the [ListBackupRetentionPoliciesRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.postgresql.v1.backup_retention_policy_pb2.BackupRetentionPolicy]:
        """List of [BackupRetentionPolicy] associated with the cluster."""

    def __init__(
        self,
        *,
        policies: collections.abc.Iterable[yandex.cloud.mdb.postgresql.v1.backup_retention_policy_pb2.BackupRetentionPolicy] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "policies", b"policies"]) -> None: ...

global___ListBackupRetentionPoliciesResponse = ListBackupRetentionPoliciesResponse

@typing.final
class CreateBackupRetentionPolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CRON_FIELD_NUMBER: builtins.int
    RETAIN_FOR_DAYS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    POLICY_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster.
    To get the PostgreSQL cluster ID use a [ClusterService.List] request.
    """
    retain_for_days: builtins.int
    """Retention duration."""
    description: builtins.str
    """Policy description."""
    policy_name: builtins.str
    """Required. Policy name."""
    @property
    def cron(self) -> yandex.cloud.mdb.postgresql.v1.backup_retention_policy_pb2.CronTab:
        """CronTab schedule."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        cron: yandex.cloud.mdb.postgresql.v1.backup_retention_policy_pb2.CronTab | None = ...,
        retain_for_days: builtins.int = ...,
        description: builtins.str = ...,
        policy_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cron", b"cron"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "cron", b"cron", "description", b"description", "policy_name", b"policy_name", "retain_for_days", b"retain_for_days"]) -> None: ...

global___CreateBackupRetentionPolicyRequest = CreateBackupRetentionPolicyRequest

@typing.final
class CreateBackupRetentionPolicyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_FIELD_NUMBER: builtins.int
    @property
    def policy(self) -> yandex.cloud.mdb.postgresql.v1.backup_retention_policy_pb2.BackupRetentionPolicy:
        """Newly created [BackupRetentionPolicy]."""

    def __init__(
        self,
        *,
        policy: yandex.cloud.mdb.postgresql.v1.backup_retention_policy_pb2.BackupRetentionPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["policy", b"policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["policy", b"policy"]) -> None: ...

global___CreateBackupRetentionPolicyResponse = CreateBackupRetentionPolicyResponse

@typing.final
class DeleteBackupRetentionPolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """Unique identifier for the [BackupRetentionPolicy]."""
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster.
    To get the PostgreSQL cluster ID use a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "policy_id", b"policy_id"]) -> None: ...

global___DeleteBackupRetentionPolicyRequest = DeleteBackupRetentionPolicyRequest

@typing.final
class DeleteBackupRetentionPolicyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteBackupRetentionPolicyResponse = DeleteBackupRetentionPolicyResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/assistants/v1/common.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/assistants/v1/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/ai/assistants/v1/common.proto\x12\x1dyandex.cloud.ai.assistants.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xf2\x02\n\x17PromptTruncationOptions\x12\x36\n\x11max_prompt_tokens\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\\\n\rauto_strategy\x18\x02 \x01(\x0b\x32\x43.yandex.cloud.ai.assistants.v1.PromptTruncationOptions.AutoStrategyH\x00\x12m\n\x16last_messages_strategy\x18\x03 \x01(\x0b\x32K.yandex.cloud.ai.assistants.v1.PromptTruncationOptions.LastMessagesStrategyH\x00\x1a\x0e\n\x0c\x41utoStrategy\x1a,\n\x14LastMessagesStrategy\x12\x14\n\x0cnum_messages\x18\x01 \x01(\x03\x42\x14\n\x12TruncationStrategy\"w\n\x11\x43ompletionOptions\x12/\n\nmax_tokens\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0btemperature\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"\x9b\x01\n\x04Tool\x12\x46\n\x0csearch_index\x18\x01 \x01(\x0b\x32..yandex.cloud.ai.assistants.v1.SearchIndexToolH\x00\x12?\n\x08\x66unction\x18\x02 \x01(\x0b\x32+.yandex.cloud.ai.assistants.v1.FunctionToolH\x00\x42\n\n\x08ToolType\"`\n\x08ToolCall\x12\x44\n\rfunction_call\x18\x01 \x01(\x0b\x32+.yandex.cloud.ai.assistants.v1.FunctionCallH\x00\x42\x0e\n\x0cToolCallType\"K\n\x0cToolCallList\x12;\n\ntool_calls\x18\x01 \x03(\x0b\x32\'.yandex.cloud.ai.assistants.v1.ToolCall\"h\n\nToolResult\x12H\n\x0f\x66unction_result\x18\x01 \x01(\x0b\x32-.yandex.cloud.ai.assistants.v1.FunctionResultH\x00\x42\x10\n\x0eToolResultType\"Q\n\x0eToolResultList\x12?\n\x0ctool_results\x18\x01 \x03(\x0b\x32).yandex.cloud.ai.assistants.v1.ToolResult\"a\n\x0fSearchIndexTool\x12\x18\n\x10search_index_ids\x18\x01 \x03(\t\x12\x34\n\x0fmax_num_results\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"^\n\x0c\x46unctionTool\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12+\n\nparameters\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"H\n\x0c\x46unctionCall\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\targuments\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"@\n\x0e\x46unctionResult\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\x07\x63ontent\x18\x02 \x01(\tH\x00\x42\r\n\x0b\x43ontentTypeBq\n!yandex.cloud.api.ai.assistants.v1ZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1;assistantsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.ai.assistants.v1ZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1;assistants'
  _globals['_PROMPTTRUNCATIONOPTIONS']._serialized_start=140
  _globals['_PROMPTTRUNCATIONOPTIONS']._serialized_end=510
  _globals['_PROMPTTRUNCATIONOPTIONS_AUTOSTRATEGY']._serialized_start=428
  _globals['_PROMPTTRUNCATIONOPTIONS_AUTOSTRATEGY']._serialized_end=442
  _globals['_PROMPTTRUNCATIONOPTIONS_LASTMESSAGESSTRATEGY']._serialized_start=444
  _globals['_PROMPTTRUNCATIONOPTIONS_LASTMESSAGESSTRATEGY']._serialized_end=488
  _globals['_COMPLETIONOPTIONS']._serialized_start=512
  _globals['_COMPLETIONOPTIONS']._serialized_end=631
  _globals['_TOOL']._serialized_start=634
  _globals['_TOOL']._serialized_end=789
  _globals['_TOOLCALL']._serialized_start=791
  _globals['_TOOLCALL']._serialized_end=887
  _globals['_TOOLCALLLIST']._serialized_start=889
  _globals['_TOOLCALLLIST']._serialized_end=964
  _globals['_TOOLRESULT']._serialized_start=966
  _globals['_TOOLRESULT']._serialized_end=1070
  _globals['_TOOLRESULTLIST']._serialized_start=1072
  _globals['_TOOLRESULTLIST']._serialized_end=1153
  _globals['_SEARCHINDEXTOOL']._serialized_start=1155
  _globals['_SEARCHINDEXTOOL']._serialized_end=1252
  _globals['_FUNCTIONTOOL']._serialized_start=1254
  _globals['_FUNCTIONTOOL']._serialized_end=1348
  _globals['_FUNCTIONCALL']._serialized_start=1350
  _globals['_FUNCTIONCALL']._serialized_end=1422
  _globals['_FUNCTIONRESULT']._serialized_start=1424
  _globals['_FUNCTIONRESULT']._serialized_end=1488
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/postgresql/v1/backup_retention_policy_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/postgresql/v1/backup_retention_policy_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.mdb.postgresql.v1 import backup_retention_policy_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_backup__retention__policy__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDyandex/cloud/mdb/postgresql/v1/backup_retention_policy_service.proto\x12\x1eyandex.cloud.mdb.postgresql.v1\x1a\x1cgoogle/api/annotations.proto\x1a<yandex/cloud/mdb/postgresql/v1/backup_retention_policy.proto\x1a\x1dyandex/cloud/validation.proto\"\x84\x01\n\"ListBackupRetentionPoliciesRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x87\x01\n#ListBackupRetentionPoliciesResponse\x12G\n\x08policies\x18\x01 \x03(\x0b\x32\x35.yandex.cloud.mdb.postgresql.v1.BackupRetentionPolicy\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc6\x01\n\"CreateBackupRetentionPolicyRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x04\x63ron\x18\x02 \x01(\x0b\x32\'.yandex.cloud.mdb.postgresql.v1.CronTab\x12\x17\n\x0fretain_for_days\x18\x03 \x01(\x03\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x19\n\x0bpolicy_name\x18\x05 \x01(\tB\x04\xe8\xc7\x31\x01\"l\n#CreateBackupRetentionPolicyResponse\x12\x45\n\x06policy\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.postgresql.v1.BackupRetentionPolicy\"Y\n\"DeleteBackupRetentionPolicyRequest\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12 \n\ncluster_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"%\n#DeleteBackupRetentionPolicyResponse2\xc2\x05\n\x1c\x42\x61\x63kupRetentionPolicyService\x12\xd8\x01\n\x04List\x12\x42.yandex.cloud.mdb.postgresql.v1.ListBackupRetentionPoliciesRequest\x1a\x43.yandex.cloud.mdb.postgresql.v1.ListBackupRetentionPoliciesResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/managed-postgresql/v1/clusters/{cluster_id}/retention_policies\x12\xdd\x01\n\x06\x43reate\x12\x42.yandex.cloud.mdb.postgresql.v1.CreateBackupRetentionPolicyRequest\x1a\x43.yandex.cloud.mdb.postgresql.v1.CreateBackupRetentionPolicyResponse\"J\x82\xd3\xe4\x93\x02\x44\"?/managed-postgresql/v1/clusters/{cluster_id}/retention_policies:\x01*\x12\xe6\x01\n\x06\x44\x65lete\x12\x42.yandex.cloud.mdb.postgresql.v1.DeleteBackupRetentionPolicyRequest\x1a\x43.yandex.cloud.mdb.postgresql.v1.DeleteBackupRetentionPolicyResponse\"S\x82\xd3\xe4\x93\x02M*K/managed-postgresql/v1/clusters/{cluster_id}/retention_policies/{policy_id}Bs\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresql'
  _globals['_LISTBACKUPRETENTIONPOLICIESREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTBACKUPRETENTIONPOLICIESREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTBACKUPRETENTIONPOLICIESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTBACKUPRETENTIONPOLICIESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTBACKUPRETENTIONPOLICIESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTBACKUPRETENTIONPOLICIESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATEBACKUPRETENTIONPOLICYREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATEBACKUPRETENTIONPOLICYREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEBACKUPRETENTIONPOLICYREQUEST'].fields_by_name['policy_name']._loaded_options = None
  _globals['_CREATEBACKUPRETENTIONPOLICYREQUEST'].fields_by_name['policy_name']._serialized_options = b'\350\3071\001'
  _globals['_DELETEBACKUPRETENTIONPOLICYREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETEBACKUPRETENTIONPOLICYREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BACKUPRETENTIONPOLICYSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_BACKUPRETENTIONPOLICYSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002A\022?/managed-postgresql/v1/clusters/{cluster_id}/retention_policies'
  _globals['_BACKUPRETENTIONPOLICYSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_BACKUPRETENTIONPOLICYSERVICE'].methods_by_name['Create']._serialized_options = b'\202\323\344\223\002D\"?/managed-postgresql/v1/clusters/{cluster_id}/retention_policies:\001*'
  _globals['_BACKUPRETENTIONPOLICYSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_BACKUPRETENTIONPOLICYSERVICE'].methods_by_name['Delete']._serialized_options = b'\202\323\344\223\002M*K/managed-postgresql/v1/clusters/{cluster_id}/retention_policies/{policy_id}'
  _globals['_LISTBACKUPRETENTIONPOLICIESREQUEST']._serialized_start=228
  _globals['_LISTBACKUPRETENTIONPOLICIESREQUEST']._serialized_end=360
  _globals['_LISTBACKUPRETENTIONPOLICIESRESPONSE']._serialized_start=363
  _globals['_LISTBACKUPRETENTIONPOLICIESRESPONSE']._serialized_end=498
  _globals['_CREATEBACKUPRETENTIONPOLICYREQUEST']._serialized_start=501
  _globals['_CREATEBACKUPRETENTIONPOLICYREQUEST']._serialized_end=699
  _globals['_CREATEBACKUPRETENTIONPOLICYRESPONSE']._serialized_start=701
  _globals['_CREATEBACKUPRETENTIONPOLICYRESPONSE']._serialized_end=809
  _globals['_DELETEBACKUPRETENTIONPOLICYREQUEST']._serialized_start=811
  _globals['_DELETEBACKUPRETENTIONPOLICYREQUEST']._serialized_end=900
  _globals['_DELETEBACKUPRETENTIONPOLICYRESPONSE']._serialized_start=902
  _globals['_DELETEBACKUPRETENTIONPOLICYRESPONSE']._serialized_end=939
  _globals['_BACKUPRETENTIONPOLICYSERVICE']._serialized_start=942
  _globals['_BACKUPRETENTIONPOLICYSERVICE']._serialized_end=1648
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/spqr/v1/host.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/spqr/v1/host.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.mdb.spqr.v1 import config_pb2 as yandex_dot_cloud_dot_mdb_dot_spqr_dot_v1_dot_config__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#yandex/cloud/mdb/spqr/v1/host.proto\x12\x18yandex.cloud.mdb.spqr.v1\x1a%yandex/cloud/mdb/spqr/v1/config.proto\x1a\x1dyandex/cloud/validation.proto\"\xf1\x08\n\x04Host\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x0f\n\x07zone_id\x18\x03 \x01(\t\x12\x36\n\tresources\x18\x04 \x01(\x0b\x32#.yandex.cloud.mdb.spqr.v1.Resources\x12\x31\n\x04role\x18\x05 \x01(\x0e\x32#.yandex.cloud.mdb.spqr.v1.Host.Role\x12\x35\n\x06health\x18\x06 \x01(\x0e\x32%.yandex.cloud.mdb.spqr.v1.Host.Health\x12\x33\n\x08services\x18\x07 \x03(\x0b\x32!.yandex.cloud.mdb.spqr.v1.Service\x12\x11\n\tsubnet_id\x18\x08 \x01(\t\x12\x18\n\x10\x61ssign_public_ip\x18\t \x01(\x08\x12\x31\n\x04type\x18\n \x01(\x0e\x32#.yandex.cloud.mdb.spqr.v1.Host.Type\x12\x12\n\nwalle_link\x18\x0b \x01(\t\x12\x14\n\x0cstate_reason\x18\x0c \x01(\t\x12<\n\x06system\x18\r \x01(\x0b\x32,.yandex.cloud.mdb.spqr.v1.Host.SystemMetrics\x12\x12\n\nshard_name\x18\x0e \x01(\t\x1a,\n\tCPUMetric\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x0c\n\x04used\x18\x02 \x01(\x01\x1a>\n\x0cMemoryMetric\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x0c\n\x04used\x18\x02 \x01(\x03\x12\r\n\x05total\x18\x03 \x01(\x03\x1a<\n\nDiskMetric\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x0c\n\x04used\x18\x02 \x01(\x03\x12\r\n\x05total\x18\x03 \x01(\x03\x1a\xbc\x01\n\rSystemMetrics\x12\x35\n\x03\x63pu\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.spqr.v1.Host.CPUMetric\x12;\n\x06memory\x18\x02 \x01(\x0b\x32+.yandex.cloud.mdb.spqr.v1.Host.MemoryMetric\x12\x37\n\x04\x64isk\x18\x03 \x01(\x0b\x32).yandex.cloud.mdb.spqr.v1.Host.DiskMetric\"\x87\x01\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06ROUTER\x10\x02\x12\x0f\n\x0b\x43OORDINATOR\x10\x03\x12\t\n\x05INFRA\x10\x04\x12\x0e\n\nPOSTGRESQL\x10\x05\x12\x17\n\x13\x45XTERNAL_POSTGRESQL\x10\x06\x12\x12\n\x0eMDB_POSTGRESQL\x10\x07\"\x04\x08\x01\x10\x01\"M\n\x04Role\x12\x10\n\x0cROLE_UNKNOWN\x10\x00\x12\x0b\n\x07PRIMARY\x10\x01\x12\r\n\tSECONDARY\x10\x02\x12\n\n\x06MASTER\x10\x03\x12\x0b\n\x07REPLICA\x10\x04\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"\xb6\x02\n\x07Service\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.yandex.cloud.mdb.spqr.v1.Service.Type\x12\x38\n\x06health\x18\x02 \x01(\x0e\x32(.yandex.cloud.mdb.spqr.v1.Service.Health\"\x87\x01\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06ROUTER\x10\x02\x12\x0f\n\x0b\x43OORDINATOR\x10\x03\x12\t\n\x05INFRA\x10\x04\x12\x0e\n\nPOSTGRESQL\x10\x05\x12\x17\n\x13\x45XTERNAL_POSTGRESQL\x10\x06\x12\x12\n\x0eMDB_POSTGRESQL\x10\x07\"\x04\x08\x01\x10\x01\"1\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\"\x86\x02\n\x08HostSpec\x12\x19\n\x07zone_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1b\n\tsubnet_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x61ssign_public_ip\x18\x03 \x01(\x08\x12\x37\n\x04type\x18\x04 \x01(\x0e\x32#.yandex.cloud.mdb.spqr.v1.Host.TypeB\x04\xe8\xc7\x31\x01\x12.\n\nshard_name\x18\x05 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12?\n\x0emdb_postgresql\x18\x06 \x01(\x0b\x32\'.yandex.cloud.mdb.spqr.v1.MDBPostgreSQLBa\n\x1cyandex.cloud.api.mdb.spqr.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/spqr/v1;spqrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.spqr.v1.host_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034yandex.cloud.api.mdb.spqr.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/spqr/v1;spqr'
  _globals['_HOSTSPEC'].fields_by_name['zone_id']._loaded_options = None
  _globals['_HOSTSPEC'].fields_by_name['zone_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_HOSTSPEC'].fields_by_name['subnet_id']._loaded_options = None
  _globals['_HOSTSPEC'].fields_by_name['subnet_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_HOSTSPEC'].fields_by_name['type']._loaded_options = None
  _globals['_HOSTSPEC'].fields_by_name['type']._serialized_options = b'\350\3071\001'
  _globals['_HOSTSPEC'].fields_by_name['shard_name']._loaded_options = None
  _globals['_HOSTSPEC'].fields_by_name['shard_name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_HOST']._serialized_start=136
  _globals['_HOST']._serialized_end=1273
  _globals['_HOST_CPUMETRIC']._serialized_start=630
  _globals['_HOST_CPUMETRIC']._serialized_end=674
  _globals['_HOST_MEMORYMETRIC']._serialized_start=676
  _globals['_HOST_MEMORYMETRIC']._serialized_end=738
  _globals['_HOST_DISKMETRIC']._serialized_start=740
  _globals['_HOST_DISKMETRIC']._serialized_end=800
  _globals['_HOST_SYSTEMMETRICS']._serialized_start=803
  _globals['_HOST_SYSTEMMETRICS']._serialized_end=991
  _globals['_HOST_TYPE']._serialized_start=994
  _globals['_HOST_TYPE']._serialized_end=1129
  _globals['_HOST_ROLE']._serialized_start=1131
  _globals['_HOST_ROLE']._serialized_end=1208
  _globals['_HOST_HEALTH']._serialized_start=1210
  _globals['_HOST_HEALTH']._serialized_end=1273
  _globals['_SERVICE']._serialized_start=1276
  _globals['_SERVICE']._serialized_end=1586
  _globals['_SERVICE_TYPE']._serialized_start=994
  _globals['_SERVICE_TYPE']._serialized_end=1129
  _globals['_SERVICE_HEALTH']._serialized_start=1210
  _globals['_SERVICE_HEALTH']._serialized_end=1259
  _globals['_HOSTSPEC']._serialized_start=1589
  _globals['_HOSTSPEC']._serialized_end=1851
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RecognitionClassifierResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_TIME_MS_FIELD_NUMBER: builtins.int
    END_TIME_MS_FIELD_NUMBER: builtins.int
    CLASSIFIER_FIELD_NUMBER: builtins.int
    HIGHLIGHTS_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    start_time_ms: builtins.int
    """Start time of the audio segment used for classification"""
    end_time_ms: builtins.int
    """End time of the audio segment used for classification"""
    classifier: builtins.str
    """Name of the triggered classifier"""
    @property
    def highlights(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PhraseHighlight]:
        """List of highlights, i.e. parts of phrase that determine the result of the classification"""

    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecognitionClassifierLabel]:
        """Classifier predictions"""

    def __init__(
        self,
        *,
        start_time_ms: builtins.int = ...,
        end_time_ms: builtins.int = ...,
        classifier: builtins.str = ...,
        highlights: collections.abc.Iterable[global___PhraseHighlight] | None = ...,
        labels: collections.abc.Iterable[global___RecognitionClassifierLabel] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["classifier", b"classifier", "end_time_ms", b"end_time_ms", "highlights", b"highlights", "labels", b"labels", "start_time_ms", b"start_time_ms"]) -> None: ...

global___RecognitionClassifierResult = RecognitionClassifierResult

@typing.final
class PhraseHighlight(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Text transcription of the highlighted audio segment"""
    offset: builtins.int
    """offset in symbols from the beginning of whole phrase where highlight begins"""
    count: builtins.int
    """count of symbols in highlighted text"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        offset: builtins.int = ...,
        count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["count", b"count", "offset", b"offset", "text", b"text"]) -> None: ...

global___PhraseHighlight = PhraseHighlight

@typing.final
class RecognitionClassifierLabel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LABEL_FIELD_NUMBER: builtins.int
    CONFIDENCE_FIELD_NUMBER: builtins.int
    label: builtins.str
    """The label of the class predicted by the classifier"""
    confidence: builtins.float
    """The prediction confidence"""
    def __init__(
        self,
        *,
        label: builtins.str = ...,
        confidence: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["confidence", b"confidence", "label", b"label"]) -> None: ...

global___RecognitionClassifierLabel = RecognitionClassifierLabel



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RateLimit(google.protobuf.message.Message):
    """RateLimit is a set of settings for global rate limiting."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Limit(google.protobuf.message.Message):
        """Limit is a rate limit value settings."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PER_SECOND_FIELD_NUMBER: builtins.int
        PER_MINUTE_FIELD_NUMBER: builtins.int
        per_second: builtins.int
        """PerSecond is a limit value specified with per second time unit."""
        per_minute: builtins.int
        """PerMinute is a limit value specified with per minute time unit."""
        def __init__(
            self,
            *,
            per_second: builtins.int = ...,
            per_minute: builtins.int = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["per_minute", b"per_minute", "per_second", b"per_second", "rate", b"rate"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["per_minute", b"per_minute", "per_second", b"per_second", "rate", b"rate"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["rate", b"rate"]) -> typing.Literal["per_second", "per_minute"] | None: ...

    ALL_REQUESTS_FIELD_NUMBER: builtins.int
    REQUESTS_PER_IP_FIELD_NUMBER: builtins.int
    @property
    def all_requests(self) -> global___RateLimit.Limit:
        """AllRequests is a rate limit configuration applied to all incoming requests."""

    @property
    def requests_per_ip(self) -> global___RateLimit.Limit:
        """RequestsPerIp is a rate limit configuration applied separately for each set of requests
        grouped by client IP address.
        """

    def __init__(
        self,
        *,
        all_requests: global___RateLimit.Limit | None = ...,
        requests_per_ip: global___RateLimit.Limit | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["all_requests", b"all_requests", "requests_per_ip", b"requests_per_ip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["all_requests", b"all_requests", "requests_per_ip", b"requests_per_ip"]) -> None: ...

global___RateLimit = RateLimit



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.logging.v1.log_entry_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MetadataOption:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MetadataOptionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MetadataOption.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    METADATA_OPTION_UNSPECIFIED: _MetadataOption.ValueType  # 0
    """Option is default"""
    ENABLED: _MetadataOption.ValueType  # 1
    """Option is enabled"""
    DISABLED: _MetadataOption.ValueType  # 2
    """Option is disabled"""

class MetadataOption(_MetadataOption, metaclass=_MetadataOptionEnumTypeWrapper): ...

METADATA_OPTION_UNSPECIFIED: MetadataOption.ValueType  # 0
"""Option is default"""
ENABLED: MetadataOption.ValueType  # 1
"""Option is enabled"""
DISABLED: MetadataOption.ValueType  # 2
"""Option is disabled"""
global___MetadataOption = MetadataOption

@typing.final
class Function(google.protobuf.message.Message):
    """A serverless function. For details about the concept, see [Functions](/docs/functions/concepts/function)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Function._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Function._Status.ValueType  # 0
        CREATING: Function._Status.ValueType  # 1
        """Function is being created."""
        ACTIVE: Function._Status.ValueType  # 2
        """Function is ready to be invoked."""
        DELETING: Function._Status.ValueType  # 3
        """Function is being deleted."""
        ERROR: Function._Status.ValueType  # 4
        """Function failed."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Function.Status.ValueType  # 0
    CREATING: Function.Status.ValueType  # 1
    """Function is being created."""
    ACTIVE: Function.Status.ValueType  # 2
    """Function is ready to be invoked."""
    DELETING: Function.Status.ValueType  # 3
    """Function is being deleted."""
    ERROR: Function.Status.ValueType  # 4
    """Function failed."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    HTTP_INVOKE_URL_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the function. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the function belongs to."""
    name: builtins.str
    """Name of the function. The name is unique within the folder."""
    description: builtins.str
    """Description of the function."""
    http_invoke_url: builtins.str
    """URL that needs to be requested to invoke the function."""
    status: global___Function.Status.ValueType
    """Status of the function."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp for the function."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Function labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        http_invoke_url: builtins.str = ...,
        status: global___Function.Status.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "http_invoke_url", b"http_invoke_url", "id", b"id", "labels", b"labels", "name", b"name", "status", b"status"]) -> None: ...

global___Function = Function

@typing.final
class Version(google.protobuf.message.Message):
    """Version of a function. For details about the concept, see [Function versions](/docs/functions/concepts/function#version)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Version._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Version._Status.ValueType  # 0
        CREATING: Version._Status.ValueType  # 1
        """Version is being created."""
        ACTIVE: Version._Status.ValueType  # 2
        """Version is ready to use."""
        OBSOLETE: Version._Status.ValueType  # 3
        """Version will be deleted soon."""
        DELETING: Version._Status.ValueType  # 4
        """Version is being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Version.Status.ValueType  # 0
    CREATING: Version.Status.ValueType  # 1
    """Version is being created."""
    ACTIVE: Version.Status.ValueType  # 2
    """Version is ready to use."""
    OBSOLETE: Version.Status.ValueType  # 3
    """Version will be deleted soon."""
    DELETING: Version.Status.ValueType  # 4
    """Version is being deleted."""

    @typing.final
    class EnvironmentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class NamedServiceAccountsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FUNCTION_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    ENTRYPOINT_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    EXECUTION_TIMEOUT_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    IMAGE_SIZE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    CONNECTIVITY_FIELD_NUMBER: builtins.int
    NAMED_SERVICE_ACCOUNTS_FIELD_NUMBER: builtins.int
    SECRETS_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    STORAGE_MOUNTS_FIELD_NUMBER: builtins.int
    ASYNC_INVOCATION_CONFIG_FIELD_NUMBER: builtins.int
    TMPFS_SIZE_FIELD_NUMBER: builtins.int
    CONCURRENCY_FIELD_NUMBER: builtins.int
    MOUNTS_FIELD_NUMBER: builtins.int
    METADATA_OPTIONS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the version."""
    function_id: builtins.str
    """ID of the function that the version belongs to."""
    description: builtins.str
    """Description of the version."""
    runtime: builtins.str
    """ID of the runtime environment for the function.

    Supported environments and their identifiers are listed in the [Runtime environments](/docs/functions/concepts/runtime).
    """
    entrypoint: builtins.str
    """Entrypoint for the function: the name of the function to be called as the handler.

    Specified in the format `<function file name>.<handler name>`, for example, `index.myFunction`.
    """
    service_account_id: builtins.str
    """ID of the service account associated with the version."""
    image_size: builtins.int
    """Final size of the deployment package after unpacking."""
    status: global___Version.Status.ValueType
    """Status of the version."""
    tmpfs_size: builtins.int
    """Optional size of in-memory mounted /tmp directory in bytes."""
    concurrency: builtins.int
    """The maximum number of requests processed by a function instance at the same time"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp for the version."""

    @property
    def resources(self) -> global___Resources:
        """Resources allocated to the version."""

    @property
    def execution_timeout(self) -> google.protobuf.duration_pb2.Duration:
        """Timeout for the execution of the version.

        If the timeout is exceeded, Cloud Functions responds with a 504 HTTP code.
        """

    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Version tags. For details, see [Version tag](/docs/functions/concepts/function#tag)."""

    @property
    def environment(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Environment settings for the version."""

    @property
    def connectivity(self) -> global___Connectivity:
        """Network access. If specified the version will be attached to specified network/subnet(s)."""

    @property
    def named_service_accounts(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Additional service accounts to be used by the version."""

    @property
    def secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Secret]:
        """Yandex Lockbox secrets to be used by the version."""

    @property
    def log_options(self) -> global___LogOptions:
        """Options for logging from the function"""

    @property
    def storage_mounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageMount]:
        """S3 mounts to be used by the version."""

    @property
    def async_invocation_config(self) -> global___AsyncInvocationConfig:
        """Config for asynchronous invocations of the version"""

    @property
    def mounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Mount]:
        """Mounts to be used by the version."""

    @property
    def metadata_options(self) -> global___MetadataOptions:
        """Metadata options for the version."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        function_id: builtins.str = ...,
        description: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        runtime: builtins.str = ...,
        entrypoint: builtins.str = ...,
        resources: global___Resources | None = ...,
        execution_timeout: google.protobuf.duration_pb2.Duration | None = ...,
        service_account_id: builtins.str = ...,
        image_size: builtins.int = ...,
        status: global___Version.Status.ValueType = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        environment: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        connectivity: global___Connectivity | None = ...,
        named_service_accounts: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        secrets: collections.abc.Iterable[global___Secret] | None = ...,
        log_options: global___LogOptions | None = ...,
        storage_mounts: collections.abc.Iterable[global___StorageMount] | None = ...,
        async_invocation_config: global___AsyncInvocationConfig | None = ...,
        tmpfs_size: builtins.int = ...,
        concurrency: builtins.int = ...,
        mounts: collections.abc.Iterable[global___Mount] | None = ...,
        metadata_options: global___MetadataOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["async_invocation_config", b"async_invocation_config", "connectivity", b"connectivity", "created_at", b"created_at", "execution_timeout", b"execution_timeout", "log_options", b"log_options", "metadata_options", b"metadata_options", "resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["async_invocation_config", b"async_invocation_config", "concurrency", b"concurrency", "connectivity", b"connectivity", "created_at", b"created_at", "description", b"description", "entrypoint", b"entrypoint", "environment", b"environment", "execution_timeout", b"execution_timeout", "function_id", b"function_id", "id", b"id", "image_size", b"image_size", "log_options", b"log_options", "metadata_options", b"metadata_options", "mounts", b"mounts", "named_service_accounts", b"named_service_accounts", "resources", b"resources", "runtime", b"runtime", "secrets", b"secrets", "service_account_id", b"service_account_id", "status", b"status", "storage_mounts", b"storage_mounts", "tags", b"tags", "tmpfs_size", b"tmpfs_size"]) -> None: ...

global___Version = Version

@typing.final
class Resources(google.protobuf.message.Message):
    """Resources allocated to a version."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEMORY_FIELD_NUMBER: builtins.int
    memory: builtins.int
    """Amount of memory available to the version, specified in bytes, multiple of 128MB."""
    def __init__(
        self,
        *,
        memory: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["memory", b"memory"]) -> None: ...

global___Resources = Resources

@typing.final
class Package(google.protobuf.message.Message):
    """Version deployment package."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_NAME_FIELD_NUMBER: builtins.int
    OBJECT_NAME_FIELD_NUMBER: builtins.int
    SHA256_FIELD_NUMBER: builtins.int
    bucket_name: builtins.str
    """Name of the bucket that stores the code for the version."""
    object_name: builtins.str
    """Name of the object in the bucket that stores the code for the version."""
    sha256: builtins.str
    """SHA256 hash of the version deployment package."""
    def __init__(
        self,
        *,
        bucket_name: builtins.str = ...,
        object_name: builtins.str = ...,
        sha256: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bucket_name", b"bucket_name", "object_name", b"object_name", "sha256", b"sha256"]) -> None: ...

global___Package = Package

@typing.final
class Connectivity(google.protobuf.message.Message):
    """Version connectivity specification."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    """Network the version will have access to.
    It's essential to specify network with subnets in all availability zones.
    """
    @property
    def subnet_id(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Complete list of subnets (from the same network) the version can be attached to.
        It's essential to specify at least one subnet for each availability zones.
        """

    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
        subnet_id: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_id", b"network_id", "subnet_id", b"subnet_id"]) -> None: ...

global___Connectivity = Connectivity

@typing.final
class ScalingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    MODIFIED_AT_FIELD_NUMBER: builtins.int
    PROVISIONED_INSTANCES_COUNT_FIELD_NUMBER: builtins.int
    ZONE_INSTANCES_LIMIT_FIELD_NUMBER: builtins.int
    ZONE_REQUESTS_LIMIT_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """ID of the function that the scaling policy belongs to."""
    tag: builtins.str
    """Tag of the version that the scaling policy belongs to. For details, see [Version tag](/docs/functions/concepts/function#tag)."""
    provisioned_instances_count: builtins.int
    """Minimum guaranteed provisioned instances count for all zones in total.
    Billed separately.
    """
    zone_instances_limit: builtins.int
    """Upper limit for instance count in each zone.
    0 means no limit.
    """
    zone_requests_limit: builtins.int
    """Upper limit of requests count in each zone.
    0 means no limit.
    """
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp for the scaling policy"""

    @property
    def modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Modification timestamp for the scaling policy"""

    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
        tag: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        provisioned_instances_count: builtins.int = ...,
        zone_instances_limit: builtins.int = ...,
        zone_requests_limit: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "modified_at", b"modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "function_id", b"function_id", "modified_at", b"modified_at", "provisioned_instances_count", b"provisioned_instances_count", "tag", b"tag", "zone_instances_limit", b"zone_instances_limit", "zone_requests_limit", b"zone_requests_limit"]) -> None: ...

global___ScalingPolicy = ScalingPolicy

@typing.final
class Secret(google.protobuf.message.Message):
    """Secret for serverless function."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    ENVIRONMENT_VARIABLE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of Yandex Lockbox secret."""
    version_id: builtins.str
    """ID of Yandex Lockbox version."""
    key: builtins.str
    """Key in secret's payload, which value to be delivered into function environment."""
    environment_variable: builtins.str
    """environment variable in which secret's value to be delivered."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        version_id: builtins.str = ...,
        key: builtins.str = ...,
        environment_variable: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["environment_variable", b"environment_variable", "reference", b"reference"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["environment_variable", b"environment_variable", "id", b"id", "key", b"key", "reference", b"reference", "version_id", b"version_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["reference", b"reference"]) -> typing.Literal["environment_variable"] | None: ...

global___Secret = Secret

@typing.final
class LogOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    MIN_LEVEL_FIELD_NUMBER: builtins.int
    disabled: builtins.bool
    """Is logging from function disabled."""
    log_group_id: builtins.str
    """Entry should be written to log group resolved by ID."""
    folder_id: builtins.str
    """Entry should be written to default log group for specified folder."""
    min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType
    """Minimum log entry level.

    See [LogLevel.Level] for details.
    """
    def __init__(
        self,
        *,
        disabled: builtins.bool = ...,
        log_group_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destination", b"destination", "disabled", b"disabled", "folder_id", b"folder_id", "log_group_id", b"log_group_id", "min_level", b"min_level"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["log_group_id", "folder_id"] | None: ...

global___LogOptions = LogOptions

@typing.final
class StorageMount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_ID_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    MOUNT_POINT_NAME_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    bucket_id: builtins.str
    """S3 bucket name for mounting."""
    prefix: builtins.str
    """S3 bucket prefix for mounting."""
    mount_point_name: builtins.str
    """Mount point directory name (not path) for mounting."""
    read_only: builtins.bool
    """Is mount read only."""
    def __init__(
        self,
        *,
        bucket_id: builtins.str = ...,
        prefix: builtins.str = ...,
        mount_point_name: builtins.str = ...,
        read_only: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bucket_id", b"bucket_id", "mount_point_name", b"mount_point_name", "prefix", b"prefix", "read_only", b"read_only"]) -> None: ...

global___StorageMount = StorageMount

@typing.final
class Mount(google.protobuf.message.Message):
    """Mount contains an information about version's external storage mount"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Mode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Mount._Mode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        MODE_UNSPECIFIED: Mount._Mode.ValueType  # 0
        READ_ONLY: Mount._Mode.ValueType  # 1
        READ_WRITE: Mount._Mode.ValueType  # 2

    class Mode(_Mode, metaclass=_ModeEnumTypeWrapper): ...
    MODE_UNSPECIFIED: Mount.Mode.ValueType  # 0
    READ_ONLY: Mount.Mode.ValueType  # 1
    READ_WRITE: Mount.Mode.ValueType  # 2

    @typing.final
    class ObjectStorage(google.protobuf.message.Message):
        """ObjectStorage as a mount"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        BUCKET_ID_FIELD_NUMBER: builtins.int
        PREFIX_FIELD_NUMBER: builtins.int
        bucket_id: builtins.str
        """ObjectStorage bucket name for mounting."""
        prefix: builtins.str
        """ObjectStorage bucket prefix for mounting."""
        def __init__(
            self,
            *,
            bucket_id: builtins.str = ...,
            prefix: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["bucket_id", b"bucket_id", "prefix", b"prefix"]) -> None: ...

    @typing.final
    class DiskSpec(google.protobuf.message.Message):
        """Disk as a mount"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SIZE_FIELD_NUMBER: builtins.int
        BLOCK_SIZE_FIELD_NUMBER: builtins.int
        size: builtins.int
        """The size of disk for mount in bytes"""
        block_size: builtins.int
        """Optional block size of disk for mount in bytes"""
        def __init__(
            self,
            *,
            size: builtins.int = ...,
            block_size: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["block_size", b"block_size", "size", b"size"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    OBJECT_STORAGE_FIELD_NUMBER: builtins.int
    EPHEMERAL_DISK_SPEC_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Unique mount point name. Device will be mounted into /function/storage/<name>"""
    mode: global___Mount.Mode.ValueType
    """Mount's mode"""
    @property
    def object_storage(self) -> global___Mount.ObjectStorage:
        """Object storage mounts"""

    @property
    def ephemeral_disk_spec(self) -> global___Mount.DiskSpec:
        """Working disk (worker-local non-shared read-write NBS disk templates)"""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        mode: global___Mount.Mode.ValueType = ...,
        object_storage: global___Mount.ObjectStorage | None = ...,
        ephemeral_disk_spec: global___Mount.DiskSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ephemeral_disk_spec", b"ephemeral_disk_spec", "object_storage", b"object_storage", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ephemeral_disk_spec", b"ephemeral_disk_spec", "mode", b"mode", "name", b"name", "object_storage", b"object_storage", "target", b"target"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["target", b"target"]) -> typing.Literal["object_storage", "ephemeral_disk_spec"] | None: ...

global___Mount = Mount

@typing.final
class AsyncInvocationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ResponseTarget(google.protobuf.message.Message):
        """Target to which a result of an invocation will be sent"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        EMPTY_TARGET_FIELD_NUMBER: builtins.int
        YMQ_TARGET_FIELD_NUMBER: builtins.int
        @property
        def empty_target(self) -> global___EmptyTarget:
            """Target to ignore a result"""

        @property
        def ymq_target(self) -> global___YMQTarget:
            """Target to send a result to ymq"""

        def __init__(
            self,
            *,
            empty_target: global___EmptyTarget | None = ...,
            ymq_target: global___YMQTarget | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["empty_target", b"empty_target", "target", b"target", "ymq_target", b"ymq_target"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["empty_target", b"empty_target", "target", b"target", "ymq_target", b"ymq_target"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["target", b"target"]) -> typing.Literal["empty_target", "ymq_target"] | None: ...

    RETRIES_COUNT_FIELD_NUMBER: builtins.int
    SUCCESS_TARGET_FIELD_NUMBER: builtins.int
    FAILURE_TARGET_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    retries_count: builtins.int
    """Number of retries of version invocation"""
    service_account_id: builtins.str
    """Service account which can invoke version"""
    @property
    def success_target(self) -> global___AsyncInvocationConfig.ResponseTarget:
        """Target for successful result of the version's invocation"""

    @property
    def failure_target(self) -> global___AsyncInvocationConfig.ResponseTarget:
        """Target for unsuccessful result, if all retries failed"""

    def __init__(
        self,
        *,
        retries_count: builtins.int = ...,
        success_target: global___AsyncInvocationConfig.ResponseTarget | None = ...,
        failure_target: global___AsyncInvocationConfig.ResponseTarget | None = ...,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["failure_target", b"failure_target", "success_target", b"success_target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["failure_target", b"failure_target", "retries_count", b"retries_count", "service_account_id", b"service_account_id", "success_target", b"success_target"]) -> None: ...

global___AsyncInvocationConfig = AsyncInvocationConfig

@typing.final
class YMQTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUEUE_ARN_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    queue_arn: builtins.str
    """Queue ARN"""
    service_account_id: builtins.str
    """Service account which has write permission on the queue."""
    def __init__(
        self,
        *,
        queue_arn: builtins.str = ...,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["queue_arn", b"queue_arn", "service_account_id", b"service_account_id"]) -> None: ...

global___YMQTarget = YMQTarget

@typing.final
class EmptyTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___EmptyTarget = EmptyTarget

@typing.final
class MetadataOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GCE_HTTP_ENDPOINT_FIELD_NUMBER: builtins.int
    AWS_V1_HTTP_ENDPOINT_FIELD_NUMBER: builtins.int
    gce_http_endpoint: global___MetadataOption.ValueType
    """Enabled access to GCE flavored metadata"""
    aws_v1_http_endpoint: global___MetadataOption.ValueType
    """Enabled access to AWS flavored metadata (IMDSv1)"""
    def __init__(
        self,
        *,
        gce_http_endpoint: global___MetadataOption.ValueType = ...,
        aws_v1_http_endpoint: global___MetadataOption.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["aws_v1_http_endpoint", b"aws_v1_http_endpoint", "gce_http_endpoint", b"gce_http_endpoint"]) -> None: ...

global___MetadataOptions = MetadataOptions



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _LogLevel:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LogLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LogLevel.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LOG_LEVEL_UNSPECIFIED: _LogLevel.ValueType  # 0
    DEBUG: _LogLevel.ValueType  # 1
    INFO: _LogLevel.ValueType  # 2
    WARNING: _LogLevel.ValueType  # 3
    ERROR: _LogLevel.ValueType  # 4
    FATAL: _LogLevel.ValueType  # 5
    PANIC: _LogLevel.ValueType  # 6

class LogLevel(_LogLevel, metaclass=_LogLevelEnumTypeWrapper): ...

LOG_LEVEL_UNSPECIFIED: LogLevel.ValueType  # 0
DEBUG: LogLevel.ValueType  # 1
INFO: LogLevel.ValueType  # 2
WARNING: LogLevel.ValueType  # 3
ERROR: LogLevel.ValueType  # 4
FATAL: LogLevel.ValueType  # 5
PANIC: LogLevel.ValueType  # 6
global___LogLevel = LogLevel

@typing.final
class MDBPostgreSQL(google.protobuf.message.Message):
    """TODO move to hosts.proto when it's created
    Configuration for MDB PostgreSQL host
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___MDBPostgreSQL = MDBPostgreSQL

@typing.final
class SPQRConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTER_FIELD_NUMBER: builtins.int
    COORDINATOR_FIELD_NUMBER: builtins.int
    POSTGRESQL_FIELD_NUMBER: builtins.int
    INFRA_FIELD_NUMBER: builtins.int
    LOG_LEVEL_FIELD_NUMBER: builtins.int
    BALANCER_FIELD_NUMBER: builtins.int
    log_level: global___LogLevel.ValueType
    """SPQR default log level"""
    @property
    def router(self) -> global___RouterConfig:
        """SPQR router settings."""

    @property
    def coordinator(self) -> global___CoordinatorConfig:
        """SPQR coordinator settings."""

    @property
    def postgresql(self) -> global___PostgreSQLConfig:
        """PostgreSQL settings."""

    @property
    def infra(self) -> global___InfraConfig:
        """SPQR Infra (router+coordinator) settings."""

    @property
    def balancer(self) -> global___BalancerSettings:
        """SPQR Balancer settings."""

    def __init__(
        self,
        *,
        router: global___RouterConfig | None = ...,
        coordinator: global___CoordinatorConfig | None = ...,
        postgresql: global___PostgreSQLConfig | None = ...,
        infra: global___InfraConfig | None = ...,
        log_level: global___LogLevel.ValueType = ...,
        balancer: global___BalancerSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["balancer", b"balancer", "coordinator", b"coordinator", "infra", b"infra", "postgresql", b"postgresql", "router", b"router"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["balancer", b"balancer", "coordinator", b"coordinator", "infra", b"infra", "log_level", b"log_level", "postgresql", b"postgresql", "router", b"router"]) -> None: ...

global___SPQRConfig = SPQRConfig

@typing.final
class RouterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> global___RouterSettings: ...
    @property
    def resources(self) -> global___Resources: ...
    def __init__(
        self,
        *,
        config: global___RouterSettings | None = ...,
        resources: global___Resources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "resources", b"resources"]) -> None: ...

global___RouterConfig = RouterConfig

@typing.final
class CoordinatorConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> global___CoordinatorSettings: ...
    @property
    def resources(self) -> global___Resources: ...
    def __init__(
        self,
        *,
        config: global___CoordinatorSettings | None = ...,
        resources: global___Resources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "resources", b"resources"]) -> None: ...

global___CoordinatorConfig = CoordinatorConfig

@typing.final
class PostgreSQLConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> global___PostgreSQLSettings: ...
    @property
    def resources(self) -> global___Resources: ...
    def __init__(
        self,
        *,
        config: global___PostgreSQLSettings | None = ...,
        resources: global___Resources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "resources", b"resources"]) -> None: ...

global___PostgreSQLConfig = PostgreSQLConfig

@typing.final
class InfraConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCES_FIELD_NUMBER: builtins.int
    ROUTER_FIELD_NUMBER: builtins.int
    COORDINATOR_FIELD_NUMBER: builtins.int
    @property
    def resources(self) -> global___Resources: ...
    @property
    def router(self) -> global___RouterSettings: ...
    @property
    def coordinator(self) -> global___CoordinatorSettings: ...
    def __init__(
        self,
        *,
        resources: global___Resources | None = ...,
        router: global___RouterSettings | None = ...,
        coordinator: global___CoordinatorSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["coordinator", b"coordinator", "resources", b"resources", "router", b"router"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["coordinator", b"coordinator", "resources", b"resources", "router", b"router"]) -> None: ...

global___InfraConfig = InfraConfig

@typing.final
class BalancerSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CPU_THRESHOLD_FIELD_NUMBER: builtins.int
    SPACE_THRESHOLD_FIELD_NUMBER: builtins.int
    STAT_INTERVAL_SEC_FIELD_NUMBER: builtins.int
    MAX_MOVE_COUNT_FIELD_NUMBER: builtins.int
    KEYS_PER_MOVE_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    @property
    def cpu_threshold(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def space_threshold(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def stat_interval_sec(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def max_move_count(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def keys_per_move(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def timeout(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        cpu_threshold: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        space_threshold: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        stat_interval_sec: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_move_count: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        keys_per_move: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cpu_threshold", b"cpu_threshold", "keys_per_move", b"keys_per_move", "max_move_count", b"max_move_count", "space_threshold", b"space_threshold", "stat_interval_sec", b"stat_interval_sec", "timeout", b"timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cpu_threshold", b"cpu_threshold", "keys_per_move", b"keys_per_move", "max_move_count", b"max_move_count", "space_threshold", b"space_threshold", "stat_interval_sec", b"stat_interval_sec", "timeout", b"timeout"]) -> None: ...

global___BalancerSettings = BalancerSettings

@typing.final
class RouterSettings(google.protobuf.message.Message):
    """Configuration of a SPQR router."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _DefaultRouteBehavior:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _DefaultRouteBehaviorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RouterSettings._DefaultRouteBehavior.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DEFAULT_ROUTE_BEHAVIOR_UNSPECIFIED: RouterSettings._DefaultRouteBehavior.ValueType  # 0
        BLOCK: RouterSettings._DefaultRouteBehavior.ValueType  # 1
        ALLOW: RouterSettings._DefaultRouteBehavior.ValueType  # 2

    class DefaultRouteBehavior(_DefaultRouteBehavior, metaclass=_DefaultRouteBehaviorEnumTypeWrapper): ...
    DEFAULT_ROUTE_BEHAVIOR_UNSPECIFIED: RouterSettings.DefaultRouteBehavior.ValueType  # 0
    BLOCK: RouterSettings.DefaultRouteBehavior.ValueType  # 1
    ALLOW: RouterSettings.DefaultRouteBehavior.ValueType  # 2

    SHOW_NOTICE_MESSAGES_FIELD_NUMBER: builtins.int
    TIME_QUANTILES_FIELD_NUMBER: builtins.int
    DEFAULT_ROUTE_BEHAVIOR_FIELD_NUMBER: builtins.int
    PREFER_SAME_AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    default_route_behavior: global___RouterSettings.DefaultRouteBehavior.ValueType
    @property
    def show_notice_messages(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def time_quantiles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    @property
    def prefer_same_availability_zone(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        show_notice_messages: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        time_quantiles: collections.abc.Iterable[builtins.float] | None = ...,
        default_route_behavior: global___RouterSettings.DefaultRouteBehavior.ValueType = ...,
        prefer_same_availability_zone: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["prefer_same_availability_zone", b"prefer_same_availability_zone", "show_notice_messages", b"show_notice_messages"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_route_behavior", b"default_route_behavior", "prefer_same_availability_zone", b"prefer_same_availability_zone", "show_notice_messages", b"show_notice_messages", "time_quantiles", b"time_quantiles"]) -> None: ...

global___RouterSettings = RouterSettings

@typing.final
class CoordinatorSettings(google.protobuf.message.Message):
    """Configuration of a SPQR coordinator.
    TODO
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CoordinatorSettings = CoordinatorSettings

@typing.final
class PostgreSQLSettings(google.protobuf.message.Message):
    """Configuration of a PostgreSQL.
    TODO
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PostgreSQLSettings = PostgreSQLSettings

@typing.final
class Resources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    DISK_TYPE_ID_FIELD_NUMBER: builtins.int
    resource_preset_id: builtins.str
    """ID of the preset for computational resources available to a host (CPU, memory etc.).
    All available presets are listed in the [documentation](/docs/managed-spqr/concepts/instance-types).
    """
    disk_size: builtins.int
    """Volume of the storage available to a host, in bytes."""
    disk_type_id: builtins.str
    """Type of the storage environment for the host.
    Possible values:
    * network-hdd - network HDD drive,
    * network-ssd - network SSD drive,
    * local-ssd - local SSD storage.
    """
    def __init__(
        self,
        *,
        resource_preset_id: builtins.str = ...,
        disk_size: builtins.int = ...,
        disk_type_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_size", b"disk_size", "disk_type_id", b"disk_type_id", "resource_preset_id", b"resource_preset_id"]) -> None: ...

global___Resources = Resources



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ai.foundation_models.v1.image_generation.image_generation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ImageGenerationRequest(google.protobuf.message.Message):
    """Request for the service to generate an image.

    For examples of usage, see [step-by-step guide](/docs/foundation-models/operations/yandexart/request).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_URI_FIELD_NUMBER: builtins.int
    MESSAGES_FIELD_NUMBER: builtins.int
    GENERATION_OPTIONS_FIELD_NUMBER: builtins.int
    model_uri: builtins.str
    """The [model URI](/docs/foundation-models/concepts/yandexart/models) to be used for image generation."""
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.foundation_models.v1.image_generation.image_generation_pb2.Message]:
        """A list of messages representing the context for the image generation model."""

    @property
    def generation_options(self) -> yandex.cloud.ai.foundation_models.v1.image_generation.image_generation_pb2.ImageGenerationOptions:
        """Image generation options."""

    def __init__(
        self,
        *,
        model_uri: builtins.str = ...,
        messages: collections.abc.Iterable[yandex.cloud.ai.foundation_models.v1.image_generation.image_generation_pb2.Message] | None = ...,
        generation_options: yandex.cloud.ai.foundation_models.v1.image_generation.image_generation_pb2.ImageGenerationOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["generation_options", b"generation_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["generation_options", b"generation_options", "messages", b"messages", "model_uri", b"model_uri"]) -> None: ...

global___ImageGenerationRequest = ImageGenerationRequest

@typing.final
class ImageGenerationResponse(google.protobuf.message.Message):
    """Response containing generated image."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_FIELD_NUMBER: builtins.int
    MODEL_VERSION_FIELD_NUMBER: builtins.int
    image: builtins.bytes
    """The image is serialized as an array of bytes encoded in [Base64](https://en.wikipedia.org/wiki/Base64)."""
    model_version: builtins.str
    """The model version changes with each new releases."""
    def __init__(
        self,
        *,
        image: builtins.bytes = ...,
        model_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image", b"image", "model_version", b"model_version"]) -> None: ...

global___ImageGenerationResponse = ImageGenerationResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/serverless/apigateway/websocket/v1/connection_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/serverless/apigateway/websocket/v1/connection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.serverless.apigateway.websocket.v1 import connection_pb2 as yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHyandex/cloud/serverless/apigateway/websocket/v1/connection_service.proto\x12/yandex.cloud.serverless.apigateway.websocket.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a@yandex/cloud/serverless/apigateway/websocket/v1/connection.proto\";\n\x14GetConnectionRequest\x12#\n\rconnection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xfc\x01\n\x17SendToConnectionRequest\x12#\n\rconnection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1e\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x42\x10\xe8\xc7\x31\x01\x8a\xc8\x31\x08<=131072\x12_\n\x04type\x18\x03 \x01(\x0e\x32Q.yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionRequest.DataType\";\n\x08\x44\x61taType\x12\x19\n\x15\x44\x41TA_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06\x42INARY\x10\x01\x12\x08\n\x04TEXT\x10\x02\"\x1a\n\x18SendToConnectionResponse\"8\n\x11\x44isconnectRequest\x12#\n\rconnection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x14\n\x12\x44isconnectResponse2\x9a\x05\n\x11\x43onnectionService\x12\xc8\x01\n\x03Get\x12\x45.yandex.cloud.serverless.apigateway.websocket.v1.GetConnectionRequest\x1a;.yandex.cloud.serverless.apigateway.websocket.v1.Connection\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/apigateways/websocket/v1/connections/{connection_id}\x12\xe2\x01\n\x04Send\x12H.yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionRequest\x1aI.yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionResponse\"E\x82\xd3\xe4\x93\x02?\":/apigateways/websocket/v1/connections/{connection_id}:send:\x01*\x12\xd4\x01\n\nDisconnect\x12\x42.yandex.cloud.serverless.apigateway.websocket.v1.DisconnectRequest\x1a\x43.yandex.cloud.serverless.apigateway.websocket.v1.DisconnectResponse\"=\x82\xd3\xe4\x93\x02\x37*5/apigateways/websocket/v1/connections/{connection_id}B\x94\x01\n3yandex.cloud.api.serverless.apigateway.websocket.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/serverless/apigateway/websocket/v1;websocketb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n3yandex.cloud.api.serverless.apigateway.websocket.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/serverless/apigateway/websocket/v1;websocket'
  _globals['_GETCONNECTIONREQUEST'].fields_by_name['connection_id']._loaded_options = None
  _globals['_GETCONNECTIONREQUEST'].fields_by_name['connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SENDTOCONNECTIONREQUEST'].fields_by_name['connection_id']._loaded_options = None
  _globals['_SENDTOCONNECTIONREQUEST'].fields_by_name['connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SENDTOCONNECTIONREQUEST'].fields_by_name['data']._loaded_options = None
  _globals['_SENDTOCONNECTIONREQUEST'].fields_by_name['data']._serialized_options = b'\350\3071\001\212\3101\010<=131072'
  _globals['_DISCONNECTREQUEST'].fields_by_name['connection_id']._loaded_options = None
  _globals['_DISCONNECTREQUEST'].fields_by_name['connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CONNECTIONSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0027\0225/apigateways/websocket/v1/connections/{connection_id}'
  _globals['_CONNECTIONSERVICE'].methods_by_name['Send']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['Send']._serialized_options = b'\202\323\344\223\002?\":/apigateways/websocket/v1/connections/{connection_id}:send:\001*'
  _globals['_CONNECTIONSERVICE'].methods_by_name['Disconnect']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['Disconnect']._serialized_options = b'\202\323\344\223\0027*5/apigateways/websocket/v1/connections/{connection_id}'
  _globals['_GETCONNECTIONREQUEST']._serialized_start=252
  _globals['_GETCONNECTIONREQUEST']._serialized_end=311
  _globals['_SENDTOCONNECTIONREQUEST']._serialized_start=314
  _globals['_SENDTOCONNECTIONREQUEST']._serialized_end=566
  _globals['_SENDTOCONNECTIONREQUEST_DATATYPE']._serialized_start=507
  _globals['_SENDTOCONNECTIONREQUEST_DATATYPE']._serialized_end=566
  _globals['_SENDTOCONNECTIONRESPONSE']._serialized_start=568
  _globals['_SENDTOCONNECTIONRESPONSE']._serialized_end=594
  _globals['_DISCONNECTREQUEST']._serialized_start=596
  _globals['_DISCONNECTREQUEST']._serialized_end=652
  _globals['_DISCONNECTRESPONSE']._serialized_start=654
  _globals['_DISCONNECTRESPONSE']._serialized_end=674
  _globals['_CONNECTIONSERVICE']._serialized_start=677
  _globals['_CONNECTIONSERVICE']._serialized_end=1343
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/mongodb/v1/user.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/mongodb/v1/user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/mdb/mongodb/v1/user.proto\x12\x1byandex.cloud.mdb.mongodb.v1\x1a\x1dyandex/cloud/validation.proto\"f\n\x04User\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12<\n\x0bpermissions\x18\x03 \x03(\x0b\x32\'.yandex.cloud.mdb.mongodb.v1.Permission\"2\n\nPermission\x12\x15\n\rdatabase_name\x18\x01 \x01(\t\x12\r\n\x05roles\x18\x02 \x03(\t\"\x96\x01\n\x08UserSpec\x12+\n\x04name\x18\x01 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\x12\x1f\n\x08password\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x38-128\x12<\n\x0bpermissions\x18\x03 \x03(\x0b\x32\'.yandex.cloud.mdb.mongodb.v1.PermissionBj\n\x1fyandex.cloud.api.mdb.mongodb.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1;mongodbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.mongodb.v1.user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.mdb.mongodb.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1;mongodb'
  _globals['_USERSPEC'].fields_by_name['name']._loaded_options = None
  _globals['_USERSPEC'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _globals['_USERSPEC'].fields_by_name['password']._loaded_options = None
  _globals['_USERSPEC'].fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0058-128'
  _globals['_USER']._serialized_start=102
  _globals['_USER']._serialized_end=204
  _globals['_PERMISSION']._serialized_start=206
  _globals['_PERMISSION']._serialized_end=256
  _globals['_USERSPEC']._serialized_start=259
  _globals['_USERSPEC']._serialized_end=409
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cdn/v1/resource_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cdn/v1/resource_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.cdn.v1 import origin_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2
from yandex.cloud.cdn.v1 import resource_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/cdn/v1/resource_service.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/cdn/v1/origin.proto\x1a\"yandex/cloud/cdn/v1/resource.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"7\n\x12GetResourceRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"u\n\x14ListResourcesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"b\n\x15ListResourcesResponse\x12\x30\n\tresources\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.cdn.v1.Resource\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xd4\x05\n\x15\x43reateResourceRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x13\n\x05\x63name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12G\n\x06origin\x18\x03 \x01(\x0b\x32\x31.yandex.cloud.cdn.v1.CreateResourceRequest.OriginB\x04\xe8\xc7\x31\x01\x12\x44\n\x13secondary_hostnames\x18\x04 \x01(\x0b\x32\'.yandex.cloud.cdn.v1.SecondaryHostnames\x12<\n\x0forigin_protocol\x18\x05 \x01(\x0e\x32#.yandex.cloud.cdn.v1.OriginProtocol\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x07options\x18\x07 \x01(\x0b\x32$.yandex.cloud.cdn.v1.ResourceOptions\x12\x42\n\x0fssl_certificate\x18\x08 \x01(\x0b\x32).yandex.cloud.cdn.v1.SSLTargetCertificate\x12\x46\n\x06labels\x18\t \x03(\x0b\x32\x36.yandex.cloud.cdn.v1.CreateResourceRequest.LabelsEntry\x1a\x99\x01\n\x06Origin\x12\x19\n\x0forigin_group_id\x18\x01 \x01(\x03H\x00\x12\x17\n\rorigin_source\x18\x02 \x01(\tH\x00\x12I\n\x14origin_source_params\x18\x03 \x01(\x0b\x32).yandex.cloud.cdn.v1.ResourceOriginParamsH\x00\x42\x10\n\x0eorigin_variant\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n\x14ResourceOriginParams\x12\x0e\n\x06source\x18\x01 \x01(\t\x12-\n\x04meta\x18\x02 \x01(\x0b\x32\x1f.yandex.cloud.cdn.v1.OriginMeta\";\n\x16\x43reateResourceMetadata\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xa9\x04\n\x15UpdateResourceRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x34\n\x0forigin_group_id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x44\n\x13secondary_hostnames\x18\x03 \x01(\x0b\x32\'.yandex.cloud.cdn.v1.SecondaryHostnames\x12\x35\n\x07options\x18\x04 \x01(\x0b\x32$.yandex.cloud.cdn.v1.ResourceOptions\x12<\n\x0forigin_protocol\x18\x05 \x01(\x0e\x32#.yandex.cloud.cdn.v1.OriginProtocol\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x0fssl_certificate\x18\x07 \x01(\x0b\x32).yandex.cloud.cdn.v1.SSLTargetCertificate\x12\x46\n\x06labels\x18\x08 \x03(\x0b\x32\x36.yandex.cloud.cdn.v1.UpdateResourceRequest.LabelsEntry\x12\x15\n\rremove_labels\x18\t \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\";\n\x16UpdateResourceMetadata\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\":\n\x15\x44\x65leteResourceRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65leteResourceMetadata\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\":\n\x17GetProviderCNameRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"<\n\x18GetProviderCNameResponse\x12\r\n\x05\x63name\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t2\x98\x07\n\x0fResourceService\x12v\n\x03Get\x12\'.yandex.cloud.cdn.v1.GetResourceRequest\x1a\x1d.yandex.cloud.cdn.v1.Resource\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/cdn/v1/resources/{resource_id}\x12x\n\x04List\x12).yandex.cloud.cdn.v1.ListResourcesRequest\x1a*.yandex.cloud.cdn.v1.ListResourcesResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/cdn/v1/resources\x12\x9b\x01\n\x06\x43reate\x12*.yandex.cloud.cdn.v1.CreateResourceRequest\x1a!.yandex.cloud.operation.Operation\"B\xb2\xd2*\"\n\x16\x43reateResourceMetadata\x12\x08Resource\x82\xd3\xe4\x93\x02\x16\"\x11/cdn/v1/resources:\x01*\x12\xa9\x01\n\x06Update\x12*.yandex.cloud.cdn.v1.UpdateResourceRequest\x1a!.yandex.cloud.operation.Operation\"P\xb2\xd2*\"\n\x16UpdateResourceMetadata\x12\x08Resource\x82\xd3\xe4\x93\x02$2\x1f/cdn/v1/resources/{resource_id}:\x01*\x12\xb3\x01\n\x06\x44\x65lete\x12*.yandex.cloud.cdn.v1.DeleteResourceRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*/\n\x16\x44\x65leteResourceMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02!*\x1f/cdn/v1/resources/{resource_id}\x12\x92\x01\n\x10GetProviderCName\x12,.yandex.cloud.cdn.v1.GetProviderCNameRequest\x1a-.yandex.cloud.cdn.v1.GetProviderCNameResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/cdn/v1/cname/{folder_id}BV\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cdn.v1.resource_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn'
  _globals['_GETRESOURCEREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_GETRESOURCEREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTRESOURCESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTRESOURCESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTRESOURCESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTRESOURCESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTRESOURCESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTRESOURCESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATERESOURCEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATERESOURCEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATERESOURCEREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATERESOURCEREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATERESOURCEREQUEST'].fields_by_name['cname']._loaded_options = None
  _globals['_CREATERESOURCEREQUEST'].fields_by_name['cname']._serialized_options = b'\350\3071\001'
  _globals['_CREATERESOURCEREQUEST'].fields_by_name['origin']._loaded_options = None
  _globals['_CREATERESOURCEREQUEST'].fields_by_name['origin']._serialized_options = b'\350\3071\001'
  _globals['_CREATERESOURCEMETADATA'].fields_by_name['resource_id']._loaded_options = None
  _globals['_CREATERESOURCEMETADATA'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATERESOURCEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATERESOURCEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATERESOURCEREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_UPDATERESOURCEREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATERESOURCEMETADATA'].fields_by_name['resource_id']._loaded_options = None
  _globals['_UPDATERESOURCEMETADATA'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETERESOURCEREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_DELETERESOURCEREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETPROVIDERCNAMEREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_GETPROVIDERCNAMEREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESOURCESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_RESOURCESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002!\022\037/cdn/v1/resources/{resource_id}'
  _globals['_RESOURCESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_RESOURCESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\023\022\021/cdn/v1/resources'
  _globals['_RESOURCESERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_RESOURCESERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateResourceMetadata\022\010Resource\202\323\344\223\002\026\"\021/cdn/v1/resources:\001*'
  _globals['_RESOURCESERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_RESOURCESERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateResourceMetadata\022\010Resource\202\323\344\223\002$2\037/cdn/v1/resources/{resource_id}:\001*'
  _globals['_RESOURCESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_RESOURCESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteResourceMetadata\022\025google.protobuf.Empty\202\323\344\223\002!*\037/cdn/v1/resources/{resource_id}'
  _globals['_RESOURCESERVICE'].methods_by_name['GetProviderCName']._loaded_options = None
  _globals['_RESOURCESERVICE'].methods_by_name['GetProviderCName']._serialized_options = b'\202\323\344\223\002\033\022\031/cdn/v1/cname/{folder_id}'
  _globals['_GETRESOURCEREQUEST']._serialized_start=304
  _globals['_GETRESOURCEREQUEST']._serialized_end=359
  _globals['_LISTRESOURCESREQUEST']._serialized_start=361
  _globals['_LISTRESOURCESREQUEST']._serialized_end=478
  _globals['_LISTRESOURCESRESPONSE']._serialized_start=480
  _globals['_LISTRESOURCESRESPONSE']._serialized_end=578
  _globals['_CREATERESOURCEREQUEST']._serialized_start=581
  _globals['_CREATERESOURCEREQUEST']._serialized_end=1305
  _globals['_CREATERESOURCEREQUEST_ORIGIN']._serialized_start=1105
  _globals['_CREATERESOURCEREQUEST_ORIGIN']._serialized_end=1258
  _globals['_CREATERESOURCEREQUEST_LABELSENTRY']._serialized_start=1260
  _globals['_CREATERESOURCEREQUEST_LABELSENTRY']._serialized_end=1305
  _globals['_RESOURCEORIGINPARAMS']._serialized_start=1307
  _globals['_RESOURCEORIGINPARAMS']._serialized_end=1392
  _globals['_CREATERESOURCEMETADATA']._serialized_start=1394
  _globals['_CREATERESOURCEMETADATA']._serialized_end=1453
  _globals['_UPDATERESOURCEREQUEST']._serialized_start=1456
  _globals['_UPDATERESOURCEREQUEST']._serialized_end=2009
  _globals['_UPDATERESOURCEREQUEST_LABELSENTRY']._serialized_start=1260
  _globals['_UPDATERESOURCEREQUEST_LABELSENTRY']._serialized_end=1305
  _globals['_UPDATERESOURCEMETADATA']._serialized_start=2011
  _globals['_UPDATERESOURCEMETADATA']._serialized_end=2070
  _globals['_DELETERESOURCEREQUEST']._serialized_start=2072
  _globals['_DELETERESOURCEREQUEST']._serialized_end=2130
  _globals['_DELETERESOURCEMETADATA']._serialized_start=2132
  _globals['_DELETERESOURCEMETADATA']._serialized_end=2177
  _globals['_GETPROVIDERCNAMEREQUEST']._serialized_start=2179
  _globals['_GETPROVIDERCNAMEREQUEST']._serialized_end=2237
  _globals['_GETPROVIDERCNAMERESPONSE']._serialized_start=2239
  _globals['_GETPROVIDERCNAMERESPONSE']._serialized_end=2299
  _globals['_RESOURCESERVICE']._serialized_start=2302
  _globals['_RESOURCESERVICE']._serialized_end=3222
# @@protoc_insertion_point(module_scope)
